#!/bin/bash
#
# run ghpsdr3-alex radio:

. flProgs

PROG=QtRadio
LOG_PREFIX=~/ghpLogs
LOG=$LOG_PREFIX/ghpRadio3-alex.log

cd ~
echo "Running" $QTRADIO_PREFIX/$PROG

$QTRADIO_PREFIX/$PROG
## >> $LOG 2>&1 &

##tail -F $LOG
