#!/bin/bash
#
# run flrigsdr:

. flProgs

PROG=flrig
LOG_PREFIX=~/flRigLogs
LOG=$LOG_PREFIX/flRigSdr$1.log
RUN_IT="$FLRIG_PREFIX/$PROG -title FlRigSdr$1 --config-dir .flRigSdr$1 --exp"

cd ~
echo "Running" $RUN_IT
### ", log: " $LOG > $LOG

$RUN_IT
### >> $LOG 2>&1 &

###tail -F $LOG
