#!/bin/bash
#
# run flradio as receiver:

. flProgs

###PROG=flRadio
PROG=fldigi
LOG_PREFIX=~/flRadioLogs
LOG=$LOG_PREFIX/flRadioK3.log
ROLE=transmit:0
RUN_IT="$FLRADIO_PREFIX/$PROG --config-dir .flRadioK3 --hydra-role $ROLE"

cd ~
echo "Running" $RUN_IT
### ", log: " $LOG > $LOG

$RUN_IT
### --debug-audio
### >> $LOG 2>&1 &

###tail -F $LOG
