#!/bin/bash
#
# run ghpsdr3-alex dsp server:

. flProgs

PROG=dspserver
LOG_PREFIX=~/ghpLogs
LOG=$LOG_PREFIX/ghpdsp3-alex-r$1.log

cd ~
echo "Running" $PROG "from:" $GHPDSP3ALEX_PREFIX
### ", log: " $LOG > $LOG

$GHPDSP3ALEX_PREFIX/$PROG --receiver $1 --lo 0 --hpsdr --nocorrectiq
### >> $LOG 2>&1 &

###tail -F $LOG
